@@ -3,7 +3,7 @@
  * The Horde_Mime_Viewer_Zip class renders out the contents of ZIP files in
  * HTML format.
  *
- * Copyright 2000-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -127,9 +127,8 @@ class Horde_Mime_Viewer_Zip extends Horde_Mime_Viewer_Base
             $val['method'] = Horde_String::pad($val['method'], 10, ' ', STR_PAD_LEFT);
             $val['ratio'] = Horde_String::pad(sprintf("%1.1f%%", $ratio), 10, ' ', STR_PAD_LEFT);
 
-            reset($val);
-            while (list($k, $v) = each($val)) {
-                $val[$k] = $this->_textFilter($v, 'Space2html', array(
+            foreach ($val as &$v) {
+                $v = $this->_textFilter($v, 'Space2html', array(
                     'charset' => $charset,
                     'encode' => true,
                     'encode_all' => true
